@@ -106,6 +106,9 @@ class JManFb:
 
     def c_sync_proveidors(self):
         return self.select(sql=fb_consultes.sync_proveidors)
+    
+    def c_sync_agents(self):
+        return self.select(sql=fb_consultes.sync_empleats)
 
     def c_sync_clients_mrest(self):
         return self.select(sql=fb_consultes.sync_clients_mrest)
