@@ -12,11 +12,24 @@ class Articles:
     _url_get_article_lot_id = '/articles_lots/{id}'
     _url_get_article_estoc_magatzem = '/articles_estocs/{article_atribut_id}?magatzem_id={magatzem_id}'
     _url_get_article_lot_estoc_magatzem = '/articles_estocs/{article_atribut_id}/lots?magatzem_id={magatzem_id}'
+    _url_get_articles_definicions = '/articles_definicions'
     _url_post_article_lot = '/articles_lots'
 
     def __init__(self, con: JManCon):
         self._con = con
 
+    def get_articles_definicions_by_article_id(self, p_article_id: int):
+        req = self._con.get(url=self._url_get_articles_definicions+'?article_id='+str(p_article_id))
+        return req.json()
+
+    def get_articles_definicions_by_type_id(self, p_tip_article_definicio_id: int):
+        req = self._con.get(url=self._url_get_articles_definicions+'?tip_art_def_id='+str(p_tip_article_definicio_id))
+        return req.json()
+
+    def get_articles_definicions_by_definicio_id(self, p_definicio_article_id: int):
+        req = self._con.get(url=self._url_get_articles_definicions+'?definicio_art_id='+str(p_definicio_article_id))
+        return req.json()
+
     def get_article(self, p_article: int):
         req = self._con.get(url=self._url_get_articles+'/'+str(p_article))
         return req.json()
