@@ -15,5 +15,5 @@ class Tarifes:
         return req.json()
 
     def get_tarifes(self, p_tip_tarifa_id: int):
-        req = self._con.get(url=self._url_get_tarifes.format(p_tip_tarifa_id=p_tip_tarifa_id))
+        req = self._con.get(url=self._url_get_tarifes.format(tip_tarifa_id=p_tip_tarifa_id))
         return req.json()
