@@ -6,6 +6,7 @@ class Tercers:
 
     _url_get_tercers = '/tercer'
     _url_get_tercers_parametres = '/tercer/{id_tercer}/parametres'
+    _url_get_tercers_anotacions = '/tercer/{id_tercer}/anotacions'
 
     def __init__(self, con: JManCon):
         self._con = con
@@ -17,3 +18,7 @@ class Tercers:
     def get_tercer_parametres(self, p_tercer: int):
         req = self._con.get(url=Tercers._url_get_tercers_parametres.format(id_tercer=p_tercer))
         return req.json()
+
+    def get_tercer_anotacions(self, p_tercer: int):
+        req = self._con.get(url=Tercers._url_get_tercers_anotacions.format(id_tercer=p_tercer))
+        return req.json()
