@@ -5,7 +5,7 @@ from javaman.errors import JManErrorNoContent
 class Wms:
     __slots__ = '_con'
 
-    _url_estoc = '/wms/estoc?en_transicio=false&article_atribut_id={art_atrib_id}'  # &article_lot_id={art_lot_id}
+    _url_estoc = '/wms/estoc?en_transicio=false&magatzem_id={magatzem_id}&article_atribut_id={art_atrib_id}'  # &article_lot_id={art_lot_id}
     _url_get_palet_by_numero = "/unitats_logistiques/?numero_unitat={numero_unitat}"
     _url_get_palet_by_id = "/unitats_logistiques/ex/{unitat_logistica_id}"
     _url_post_palet = "/unitats_logistiques/ex"
@@ -55,10 +55,8 @@ class Wms:
         res = self._con.get(url=tmp_url)
         return res.json()
 
-    def get_estoc(self, p_article_atribut_id: int, p_article_lot_id: int = None):
-        tmp_url = Wms._url_estoc.format(art_atrib_id=p_article_atribut_id)
-        if p_article_lot_id is not None:
-            tmp_url = tmp_url.format(art_lot_id=p_article_lot_id)
+    def get_estoc(self, p_article_atribut_id: int, p_article_lot_id: int = None, p_magatzem_id: int= None):
+        tmp_url = Wms._url_estoc.format(art_atrib_id=p_article_atribut_id, magatzem_id=p_magatzem_id)
         res = self._con.get(url=tmp_url)
         return res.json()
 
