@@ -62,7 +62,7 @@ select
     CASE WHEN c_cli.COMANDA_ID IS NULL THEN cd_adr.CPOSTAL ELSE c_cli.CPOSTAL END CPOSTAL,
     CASE WHEN c_cli.COMANDA_ID IS NULL THEN cd_poble.POBLE ELSE c_cli_poble.POBLE END POBLE,
     CASE WHEN c_cli.COMANDA_ID IS NULL THEN cd_comu.PAIS_CODI ELSE c_cli_comu.PAIS_CODI END CODI_PAIS,
-    CASE WHEN c_cli.COMANDA_ID IS NULL THEN c_con.telefon ELSE c_cli.TELEFON END TELEFON,
+    CASE WHEN c_cli.COMANDA_ID IS NULL THEN coalesce(c_con.mobil ,c_con.telefon) ELSE c_cli.TELEFON END TELEFON,
     CASE WHEN c_cli.COMANDA_ID IS NULL THEN c_con.email ELSE c_cli.EMAIL END MAIL,
     cd.PES_NET, cd.PES_BRUT,
     c.obs_comanda,
